View source: R/get_interval_duration.R
| get_interval_duration | R Documentation |
Generic utility function for returning the number of days covered by an element of a grates object.
get_interval_duration(x, ...)
x |
A grouped date vector. |
... |
Not currently used. |
The number of days covered from the start to end dates for each element in the input.
# The following should be TRUE
identical(
get_interval_duration(yearmonth(2020, 1:3)),
c(31, 29, 31)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.